@@ -1,11 +1,18 @@
 """Pydantic DataCache Configuration Data Model."""
 from pathlib import Path
 
-from pydantic import BaseModel, Field
+from pydantic import Field
+
+from oteapi.models.genericconfig import AttrDict
 
 
-class DataCacheConfig(BaseModel):
-    """DataCache Configuration."""
+class DataCacheConfig(AttrDict):
+    """DataCache Configuration.
+
+    This class should not be used directly as a configuration object
+    for a strategy object, but only as a configuration field inside
+    a configuration object.
+    """
 
     cacheDir: Path = Field("oteapi", description="Cache directory.")
     accessKey: str = Field(
