@@ -78,7 +78,9 @@ class StrategyFactory:
         if (strategy_type, strategy_name) in cls.strategy_create_func[strategy_type]:
             return cls.strategy_create_func[strategy_type][
                 (strategy_type, strategy_name)
-            ].implementation(config)
+            ].implementation(
+                config  # type: ignore[arg-type]
+            )
         raise NotImplementedError(
             f"The {strategy_type.value} strategy {strategy_name!r} does not exist."
         )
@@ -103,7 +105,7 @@ class StrategyFactory:
 
         """
         if strategy_type == StrategyType.DOWNLOAD:
-            return config.downloadUrl.scheme if config.downloadUrl is not None else ""
+            return config.downloadUrl.scheme if config.downloadUrl is not None else ""  # type: ignore[union-attr]  # pylint: disable=line-too-long
         return getattr(config, strategy_type.map_to_field(), "")
 
     @classmethod
